==> plantuml-libs-5.2.0.tgz: package/distribution/material-4/Notification/AirlineSeatLegroomReduced.md <==
# AirlineSeatLegroomReduced


```text
material-4/Notification/AirlineSeatLegroomReduced
```

```text
include('material-4/Notification/AirlineSeatLegroomReduced')
```



| Illustration | AirlineSeatLegroomReduced |
| :---: | :---: |
| ![illustration for Illustration](../../material-4/Notification/AirlineSeatLegroomReduced.png) | ![illustration for AirlineSeatLegroomReduced](../../material-4/Notification/AirlineSeatLegroomReduced.Local.png) |




## AirlineSeatLegroomReduced

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('material-4/bootstrap')

' loads the Item which embeds the element AirlineSeatLegroomReduced
include('material-4/Notification/AirlineSeatLegroomReduced')

' renders the element
AirlineSeatLegroomReduced('AirlineSeatLegroomReduced', 'Airline Seat Legroom Reduced', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('material-4/bootstrap')

' loads the Item which embeds the element AirlineSeatLegroomReduced
include('material-4/Notification/AirlineSeatLegroomReduced')

' renders the element
AirlineSeatLegroomReduced('AirlineSeatLegroomReduced', 'Airline Seat Legroom Reduced', 'an optional tech label')
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/material-4/Notification/AirlineSeatLegroomReduced.md <==
# AirlineSeatLegroomReduced


```text
material-4/Notification/AirlineSeatLegroomReduced
```

```text
include('material-4/Notification/AirlineSeatLegroomReduced')
```



| Illustration | AirlineSeatLegroomReduced |
| :---: | :---: |
| ![illustration for Illustration](../../material-4/Notification/AirlineSeatLegroomReduced.png) | ![illustration for AirlineSeatLegroomReduced](../../material-4/Notification/AirlineSeatLegroomReduced.Local.png) |




## AirlineSeatLegroomReduced

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('material-4/bootstrap')

' loads the Item which embeds the element AirlineSeatLegroomReduced
include('material-4/Notification/AirlineSeatLegroomReduced')

' renders the element
AirlineSeatLegroomReduced('AirlineSeatLegroomReduced', 'Airline Seat Legroom Reduced', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('material-4/bootstrap')

' loads the Item which embeds the element AirlineSeatLegroomReduced
include('material-4/Notification/AirlineSeatLegroomReduced')

' renders the element
AirlineSeatLegroomReduced('AirlineSeatLegroomReduced', 'Airline Seat Legroom Reduced', 'an optional tech label')
@enduml
```
